@@ -9,12 +9,13 @@
 #' * [build_articles()]
 #' * [build_tutorials()]
 #' * [build_news()]
+#' * [build_redirects()]
 #'
 #' See the documentation for the each function to learn how to control
 #' that aspect of the site. This page documents options that affect the
 #' whole site.
 #'
-#' @section General config:
+#' # General config
 #' *  `destination` controls where the site will be generated, defaulting to
 #'    `docs/`. Paths are relative to the package root.
 #'
@@ -27,13 +28,19 @@
 #'    It specifies where the site will be published and is used to allow other
 #'    pkgdown sites to link to your site when needed (`vignette("linking")`),
 #'    generate a `sitemap.xml`, automatically generate a `CNAME` when
-#'    [deploying to github][deploy_site_github], generate the metadata needed
+#'    [deploying to github][build_site_github_pages()], generate the metadata needed
 #'    rich social "media cards" (`vignette("metadata")`), and more.
 #'
 #' *  `title` overrides the default site title, which is the package name.
 #'    It's used in the page title and default navbar.
 #'
-#' @section Development mode:
+#' # Navbar and footer
+#'
+#' The `navbar` and `footer` fields control the appearance of the navbar
+#' footer which appear on every page. Learn more about these fields in
+#' `vignette("customise")`.
+#'
+#' # Development mode
 #' The `development` field allows you to generate different sites for the
 #' development and released versions of your package. To use it, you first
 #' need to set the development `mode`:
@@ -45,21 +52,22 @@
 #'
 #' ### Setting development mode
 #'
-#' The development `mode` of a site controls where the site is built,
-#' the colour of the package version in the navbar, the version tooltip,
-#' and whether or not the site is indexed by search engines. There are
-#' four possible modes:
+#' The development `mode` of a site controls where the built site is placed
+#' and how it is styled (i.e. the colour of the package version in the
+#' navbar, the version tooltip), and whether or not the site is indexed by
+#' search engines. There are four possible modes:
 #'
-#' * **automatic** (`mode: auto`): automatically determines the mode based on the
-#'   version number:
+#' * **automatic** (`mode: auto`): determines the mode based on the version:
 #'
 #'   * `0.0.0.9000` (`0.0.0.*`): unreleased.
 #'   * four version components: development.
 #'   * everything else -> release.
 #'
-#' * **release** (`mode: release`), the default. Site is written to `docs/`.
-#'   Version in navbar gets the default colouring. Development badges are
-#'   not shown in the sidebar (see `?build_home`).
+#' * **release** (`mode: release`), the default. Site is written to `docs/`
+#'   and styled like a released package, even if the content is for an
+#'   unreleased or development version. Version in navbar gets the default
+#'   colouring. Development badges are not shown in the sidebar
+#'   (see `?build_home`).
 #'
 #' * **development** (`mode: devel`). Site is written to `docs/dev/`.
 #'   The navbar version gets a "danger" class and a tooltip stating these are
@@ -72,6 +80,10 @@
 #'   package is not yet on CRAN.
 #'   Development badges are shown in the sidebar (see `?build_home`).
 #'
+#' Use `mode: auto` if you want both a released and a dev site, and
+#' `mode: release` if you just want a single site. It is very rare that you
+#' will need either devel or unreleased modes.
+#'
 #' You can override the mode specified in the `_pkgdown.yml` by setting
 #' by setting `PKGDOWN_DEV_MODE` to `devel` or `release`.
 #'
@@ -122,22 +134,13 @@
 #' to danger). Finally, you can choose to override the default tooltip with
 #' `version_tooltip`.
 #'
-#' ## Page layout
-#'
-#' The `navbar`, `footer`, and `sidebar` fields control the appearance
-#' of the navbar, footer, and sidebar respectively. They have many individual
-#' options which are documented in the **Layout** section of
-#' `vignette("customise")`.
-#'
-#' @section Search:
-#' The `search` field controls the built-in search and is
-#' documented in `vignette("search")`.
-#'
-#' @section Template:
+#' # Template
 #' The `template` field is mostly used to control the appearance of the site.
-#' See `vignette("customise")` for details.
+#' See `vignette("customise")` for details. But it's also used to control
 #'
-#' There are two other `template` fields that control other aspects of the
+#' ## Other aspects
+#'
+#' There are a few other `template` fields that control other aspects of the
 #' site:
 #'
 #' *   `noindex: true` will suppress indexing of your pages by search engines:
@@ -166,16 +169,16 @@
 #'        trailing_slash_redirect: true
 #'      ```
 #'
-#' @section Analytics:
+#' ## Analytics
 #'
 #' To capture usage of your site with a web analytics tool, you can make
 #' use of the `includes` field to add the special HTML they need. This HTML
-#' is typically placed `in_header` (actually in the `<head>`), `before_body`, 
-#' or `after_body`. 
+#' is typically placed `in_header` (actually in the `<head>`), `before_body`,
+#' or `after_body`.
 #' You can learn more about how includes work in pkgdown at
 #' <https://pkgdown.r-lib.org/articles/customise.html#additional-html-and-files>.
 #'
-#' I include a few examples of popular analytics platforms below, but we 
+#' I include a few examples of popular analytics platforms below, but we
 #' recommend getting the HTML directly from the tool:
 #'
 #' *   [plausible.io](https://plausible.io):
@@ -212,8 +215,8 @@
 #'           <script data-goatcounter="https://{YOUR CODE}.goatcounter.com/count" data-goatcounter-settings="{YOUR SETTINGS}" async src="https://gc.zgo.at/count.js"></script>
 #'     ```
 #'
+#' # Source repository
 #'
-#' @section Source repository:
 #' Use the `repo` field to override pkgdown's automatically discovery
 #' of your source repository. This is used in the navbar, on the homepage,
 #' in articles and reference topics, and in the changelog (to link to issue
@@ -233,13 +236,24 @@
 #' ```
 #'
 #' * `home`: path to package home on source code repository.
-#' * `source:`: path to source of individual file in default branch.
+#' * `source`: path to source of individual file in default branch 
+#'   (more on that below).
 #' * `issue`: path to individual issue.
 #' * `user`: path to user.
 #'
 #' The varying components (e.g. path, issue number, user name) are pasted on
 #' the end of these URLs so they should have trailing `/`s.
 #'
+#' When creating the link to pacge source, we have to link to a specific
+#' branch. The default behaviour is to use current branch when in GitHub
+#' actions and `HEAD` otherwise. You can overide this default with 
+#' `repo.branch`:
+#'
+#' ```yaml
+#' repo:
+#'   branch: devel
+#' ```
+#' 
 #' pkgdown can automatically link to Jira issues as well if specify both a
 #' custom `issue` URL as well Jira project names to auto-link in
 #' `jira_projects`. You can specify as many projects as you would like:
@@ -251,16 +265,7 @@
 #'     issue: https://jira.organisation.com/jira/browse/
 #' ```
 #'
-#' pkgdown defaults to using the "HEAD" branch for source file URLs. This can
-#' be configured to use a specific branch when linking to source files by
-#' specifying a branch name:
-#'
-#' ```yaml
-#' repo:
-#'   branch: devel
-#' ```
-#'
-#' @section Deployment (`deploy`):
+#' # Deployment (`deploy`)
 #' There is a single `deploy` field
 #'
 #' *  `install_metadata` allows you to install package index metadata into
@@ -274,11 +279,7 @@
 #'      install_metadata: true
 #'    ```
 #'
-#' @section Redirects:
-#' ```{r child="man/rmd-fragments/redirects-configuration.Rmd"}
-#' ```
-#'
-#' @section Options:
+#' # Options
 #' Users with limited internet connectivity can disable CRAN checks by setting
 #' `options(pkgdown.internet = FALSE)`. This will also disable some features
 #' from pkgdown that requires an internet connectivity. However, if it is used
@@ -327,18 +328,11 @@ build_site <- function(pkg = ".",
                        preview = NA,
                        devel = FALSE,
                        new_process = !devel,
-                       install = !devel,
-                       document = "DEPRECATED") {
+                       install = !devel) {
   pkg <- as_pkgdown(pkg, override = override)
-
-  if (document != "DEPRECATED") {
-    lifecycle::deprecate_warn(
-      "1.4.0",
-      "build_site(document)",
-      details = "build_site(devel)"
-    )
-    devel <- document
-  }
+  check_bool(devel)
+  check_bool(new_process)
+  check_bool(install)
 
   if (install) {
     withr::local_temp_libpaths()
@@ -430,13 +424,19 @@ build_site_local <- function(pkg = ".",
                              preview = NA,
                              devel = TRUE) {
 
-  pkg <- section_init(pkg, depth = 0, override = override)
+  pkg <- section_init(pkg, override = override)
 
   cli::cli_rule("Building pkgdown site for package {.pkg {pkg$package}}")
   cli::cli_inform("Reading from: {src_path(path_abs(pkg$src_path))}")
   cli::cli_inform("Writing to:   {dst_path(path_abs(pkg$dst_path))}")
 
-  init_site(pkg)
+  pkgdown_sitrep(pkg)
+
+  if (!lazy) {
+    # Only force init_site() if `!lazy`
+    # if site is not initialized, it will be in build_home()
+    init_site(pkg, override)
+  }
 
   build_home(pkg, override = override, preview = FALSE)
   build_reference(
@@ -460,6 +460,8 @@ build_site_local <- function(pkg = ".",
     build_search(pkg, override = override)
   }
 
+  check_built_site(pkg)
+
   cli::cli_rule("Finished building pkgdown site for package {.pkg {pkg$package}}")
   preview_site(pkg, preview = preview)
 }
