@@ -1,21 +1,10 @@
-set_contains <- function(haystack, needles) {
-  all(needles %in% haystack)
-}
-
-split_at_linebreaks <- function(text) {
-  if (length(text) < 1)
-    return(character())
-  strsplit(text, "\\n\\s*\\n")[[1]]
-}
-
 up_path <- function(depth) {
   paste(rep.int("../", depth), collapse = "")
 }
 
 dir_depth <- function(x) {
-  x %>%
-    strsplit("") %>%
-    purrr::map_int(function(x) sum(x == "/"))
+  # length(strsplit(path, "/")[[1]]) - 1L
+  purrr::map_int(strsplit(x, ""), function(x) sum(x == "/"))
 }
 
 invert_index <- function(x) {
@@ -38,10 +27,27 @@ rstudio_save_all <- function() {
 
 is_syntactic <- function(x) x == make.names(x)
 
+auto_quote <- function(x) {
+  ifelse(is_syntactic(x), x, paste0("`", x, "`"))
+}
+
 str_trim <- function(x) gsub("^\\s+|\\s+$", "", x)
 
 str_squish <- function(x) str_trim(gsub("\\s+", " ", x))
 
+unwrap_purrr_error <- function(code) {
+  withCallingHandlers(
+    code,
+    purrr_error_indexed = function(err) {
+      cnd_signal(err$parent)
+    }
+  )
+}
+
+tr_ <- function(...) {
+  enc2utf8(gettext(..., domain = "R-pkgdown"))
+}
+
 # devtools metadata -------------------------------------------------------
 
 system_file <- function(..., package) {
@@ -68,26 +74,13 @@ src_path <- cli::combine_ansi_styles(
 )
 
 writing_file <- function(path, show) {
-  text <- dst_path(show)
-  cli::cli_inform("Writing {.run [{text}](pkgdown::preview_page('{path}'))}")
-}
-
-skip_if_no_pandoc <- function(version = "1.12.3") {
-  testthat::skip_if_not(rmarkdown::pandoc_available(version))
+  path <- as.character(path)
+  text <- dst_path(as.character(show))
+  cli::cli_inform("Writing {.run [{text}](pkgdown::preview_site(path='{path}'))}")
 }
 
 has_internet <- function() {
-  return(getOption("pkgdown.internet", default = TRUE))
-}
-
-# remove '' quoting
-# e.g. 'title' becomes title.s
-cran_unquote <- function(string) {
-  gsub("\\'(.*?)\\'", "\\1", string)
-}
-
-isFALSE <- function(x) {
-  is.logical(x) && length(x) == 1L && !is.na(x) && !x
+  getOption("pkgdown.internet", default = TRUE)
 }
 
 modify_list <- function(x, y) {
@@ -162,8 +155,9 @@ ruler <- function(width = getOption("width")) {
 get_section_level <- function(section) {
   class <- xml2::xml_attr(section, "class")
 
-  has_level <- grepl("level(\\d+)", class)
-  ifelse(has_level, as.numeric(gsub(".*section level(\\d+).*", '\\1', class)), 0)
+level <- as.numeric(re_match(class, "level(\\d+)")[[1]])
+  level[is.na(level)] <- 0
+  level
 }
 
 section_id <- function(section) {
@@ -171,12 +165,51 @@ section_id <- function(section) {
   xml2::xml_attr(h, "id")
 }
 
+on_ci <- function() {
+  isTRUE(as.logical(Sys.getenv("CI", "false")))
+}
+
+# yaml ------------------------------------------------------------
+
+print_yaml <- function(x) {
+  structure(x, class = "print_yaml")
+}
+#' @export
+print.print_yaml <- function(x, ...) {
+  cat(yaml::as.yaml(x), "\n", sep = "")
+}
+
+write_yaml <- function(x, path) {
+  yaml::write_yaml(
+    x,
+    path,
+    handlers = list(logical = yaml::verbatim_logical)
+  )
+}
+
 # Helpers for testing -----------------------------------------------------
 
-xpath_xml <- function(x, xpath) {
-  x <- xml2::xml_find_all(x, xpath)
+xpath_xml <- function(x, xpath = NULL) {
+  if (!is.null(xpath)) {
+    x <- xml2::xml_find_all(x, xpath)
+  }
   structure(x, class = c("pkgdown_xml", class(x)))
 }
+xpath_contents <- function(x, xpath) {
+  x <- xml2::xml_find_all(x, xpath)
+
+  contents <- xml2::xml_contents(x)
+  if (length(contents) == 0) {
+    NULL
+  } else {
+    xml2str(contents)
+  }
+}
+xml2str <- function(x) {
+  strings <- as.character(x, options = c("format", "no_declaration"))
+  paste0(strings, collapse = "")
+}
+
 xpath_attr <- function(x, xpath, attr) {
   gsub("\r", "", xml2::xml_attr(xml2::xml_find_all(x, xpath), attr), fixed = TRUE)
 }
@@ -191,7 +224,3 @@ print.pkgdown_xml <- function(x, ...) {
   cat(as.character(x, options = c("format", "no_declaration")), sep = "\n")
   invisible(x)
 }
-
-tr_ <- function(...) {
-  enc2utf8(gettext(..., domain = "R-pkgdown"))
-}
